Coverage for C:\Users\hjanssen\HOME\pyCharmProjects\ethz_hvl\hvl_ccb\hvl_ccb\__init__.py: 100%

# Coverage for C:\Users\hjanssen\HOME\pyCharmProjects\ethz_hvl\hvl_ccb\hvl_ccb\__init__.py : 100%

## 8 statements

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1# Copyright (c) 2019-2020 ETH Zurich, SIS ID and HVL D-ITET

2#

3"""Top-level package for HVL Common Code Base."""

4

5 __author__ = """Mikołaj Rybiński, David Graber, Henrik Menne, Alise Chachereau"""

6 __email__ = (

7 "mikolaj.rybinski@id.ethz.ch, dev@davidgraber.ch, henrik.menne@eeh.ee.ethz.ch, "

8 "chachereau@eeh.ee.ethz.ch"

9)

10 __version__ = '0.5.0'

11

12 from . import comm # noqa: F401

13 from . import dev # noqa: F401

14 from .configuration import ConfigurationMixin, configdataclass # noqa: F401

15 from .experiment_manager import ( # noqa: F401

16 ExperimentManager,

17 ExperimentStatus,

18 ExperimentError

19)